Convex Hull {#tutorial_hull}
===========

Goal
----

In this tutorial you will learn how to:

-   Use the OpenCV function @ref cv::convexHull

Theory
------

Code
----

This tutorial code's is shown lines below. You can also download it from
[here](https://github.com/opencv/opencv/tree/master/samples/cpp/tutorial_code/ShapeDescriptors/hull_demo.cpp)

@include samples/cpp/tutorial_code/ShapeDescriptors/hull_demo.cpp

Explanation
-----------

Result
------

Here it is:

![Original](images/Hull_Original_Image.jpg)
![Result](images/Hull_Result.jpg)
